summaryrefslogtreecommitdiff
path: root/include/apr_fnmatch.h
diff options
context:
space:
mode:
authorDoug MacEachern <dougm@apache.org>2000-08-02 05:26:45 +0000
committerDoug MacEachern <dougm@apache.org>2000-08-02 05:26:45 +0000
commit1a1463dbfc6e28b6a5852142b0c87d4abe33c3d9 (patch)
tree4da0bfd73d36292921960aaabc877a57e680b8c4 /include/apr_fnmatch.h
parent4dd06339dd5b46bd735c56dc3738146416f52ccf (diff)
downloadapr-1a1463dbfc6e28b6a5852142b0c87d4abe33c3d9.tar.gz
prefix libapr functions and types with apr_
git-svn-id: https://svn.apache.org/repos/asf/apr/apr/trunk@60470 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'include/apr_fnmatch.h')
-rw-r--r--include/apr_fnmatch.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/apr_fnmatch.h b/include/apr_fnmatch.h
index b04e679cf..e15663337 100644
--- a/include/apr_fnmatch.h
+++ b/include/apr_fnmatch.h
@@ -66,19 +66,19 @@ extern "C" {
* FNM_PERIOD -- Period must be matched by period
* FNM_CASE_BLIND -- Compare characters case-insensitively.
* </PRE>
* @deffunc ap_status_t ap_fnmatch(const char *pattern, const char *strings, int flags)
*/
-APR_EXPORT(ap_status_t) ap_fnmatch(const char *pattern, const char *strings,
+APR_EXPORT(apr_status_t) apr_fnmatch(const char *pattern, const char *strings,
int flags);
/**
* Determine if the given pattern is a regular expression.
* @param pattern The pattern to search for glob characters.
* @return non-zero if pattern has any glob characters in it
- * @deffunc int ap_is_fnmatch(const char *pattern)
+ * @deffunc int apr_is_fnmatch(const char *pattern)
*/
-APR_EXPORT(int) ap_is_fnmatch(const char *pattern);
+APR_EXPORT(int) apr_is_fnmatch(const char *pattern);
#ifdef __cplusplus
}
@@ -66,19 +66,19 @@ extern "C" {
* FNM_CASE_BLIND -- Compare characters case-insensitively.
* </PRE>
- * @deffunc ap_status_t ap_fnmatch(const char *pattern, const char *strings, int flags)
+ * @deffunc apr_status_t apr_fnmatch(const char *pattern, const char *strings, int flags)
*/